@@ -47,7 +47,13 @@ class SpectacleConfig : public QObject
     
     QUrl lastSaveAsLocation() const;
     QUrl lastSaveLocation() const;
-    
+
+     enum PrintKeyActionRunning : int {
+        TakeNewScreenshot = 0,
+        StartNewInstance,
+        FocusWindow
+    };
+
     private:
 
     explicit SpectacleConfig(QObject *parent = nullptr);
@@ -87,6 +93,9 @@ class SpectacleConfig : public QObject
     bool showMagnifierChecked() const;
     void setShowMagnifierChecked(bool enabled);
 
+    bool useReleaseToCapture() const;
+    void setUseReleaseToCaptureChecked(bool enabled);
+
     qreal captureDelay() const;
     void setCaptureDelay(qreal delay);
 
@@ -96,9 +105,15 @@ class SpectacleConfig : public QObject
     bool rememberLastRectangularRegion() const;
     void setRememberLastRectangularRegion(bool enabled);
 
+    bool alwaysRememberRegion() const;
+    void setAlwaysRememberRegion(bool enabled);
+
     bool useLightRegionMaskColour() const;
     void setUseLightRegionMaskColour(bool enabled);
 
+    int compressionQuality() const;
+    void setCompressionQuality(int value);
+
     SaveMode lastUsedSaveMode() const;
     void setLastUsedSaveMode(SaveMode mode);
 
@@ -114,6 +129,9 @@ class SpectacleConfig : public QObject
     QString saveImageFormat() const;
     void setSaveImageFormat(const QString &saveFmt);
 
+    PrintKeyActionRunning printKeyActionRunning() const;
+    void setPrintKeyActionRunning (PrintKeyActionRunning action);
+
     private:
 
     KSharedConfigPtr mConfig;
